#
# spec file for package netgen
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with need_clang
%bcond_with openmpi
%bcond_without ffmpeg
%bcond_without opencascade
# pytest-check is not available
%bcond_with pytest

Name:           netgen
Version:        6.2.2105
Release:        3.6
Summary:        Automatic 3D tetrahedral mesh generator
License:        LGPL-2.1-only
Group:          Productivity/Graphics/CAD
URL:            https://ngsolve.org/
Source0:        https://github.com/NGSolve/netgen/archive/refs/tags/v%{version}.tar.gz#/netgen-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Set-explicit-OBJECT-library-type-for-internal-togl.patch
# PATCH-FIX-OPENSUSE
Patch1:         0001-Disable-backtrace-generation.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-Throw-in-case-enum-value-is-unhandled.patch
# PATCH-FIX-UPSTREAM
Patch3:         0001-Throw-Exception-when-shape-has-invalid-type.patch
# PATCH-FIX-OPENSUSE -- Allow to disable download of Catch2
Patch4:         0001-Optionally-use-system-provided-Catch2.patch
# PATCH-FIX-UPSTREAM
Patch5:         0001-Optionally-prefer-system-wide-pybind11.patch
# PATCH-FIX-UPSTREAM
Patch6:         0001-Fix-signedness-for-ARM-Neon-mask-type.patch
%if %{with opencascade}
BuildRequires:  occt-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(xi)
%endif
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  libjpeg-devel
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
%if %{with pytest}
BuildRequires:  python3-numpy
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-check
%endif
BuildRequires:  pkgconfig(catch2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(zlib)
%if %{with openmpi}
BuildRequires:  metis-devel
BuildRequires:  openmpi-devel
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif
%if %{with need_clang}
BuildRequires:  llvm
BuildRequires:  llvm-clang
%else
BuildRequires:  gcc-c++ >= 7
%endif
BuildRequires:  xz
# x86 (32bit) is no longer supported upstream. Also exclude other 32 bit archs
ExcludeArch:    %{ix86} %{arm} ppc
Recommends:     %{name}-examples

%description
NETGEN is an automatic 3D tetrahedral mesh generator. It accepts
input from constructive solid geometry (CSG) or boundary
representation (BRep) from STL file format. The connection to a
geometry kernel allows the handling of IGES and STEP files. NETGEN
contains modules for mesh optimization and hierarchical mesh
refinement.

%package -n netgen-libs
Summary:        NETGEN mesher libraries
Group:          System/Libraries
Conflicts:      %{name} < %{version}
Provides:       %{name}:%{_libdir}/netgen/libngcore.so

%description -n netgen-libs
NETGEN mesh generator shared libraries.

%package devel
Summary:        Development files for netgen
# Should not depend on the netgen binary, but the cmake config is broken
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       netgen-libs = %{version}
%if %{with opencascade}
Requires:       occt-devel
%endif

%description devel
Development files for NETGEN.

%package examples
Summary:        NETGEN examples
Group:          Productivity/Graphics/CAD
Requires:       %{name} = %{version}
Conflicts:      %{name} < %{version}
Provides:       %{name}:%{_datadir}/netgen/cube.geo
BuildArch:      noarch

%description examples
Various example geometry data for NETGEN.

%package -n python3-%{name}
Summary:        NETGEN python bindings
Group:          Productivity/Graphics/CAD
Conflicts:      %{name} < %{version}
Provides:       %{name}:%{python3_sitearch}/netgen/libngpy.so

%description  -n python3-%{name}
Python bindings for NETGEN.

%prep
%autosetup -p1

%build
%if %{with need_clang}
    OPTFLAGS="$(echo %{optflags} | sed "s:-grecord-gcc-switches::g") -flto"
%else
    OPTFLAGS="%{optflags}"
%endif

# Work around broken version detection
echo "v%{version}-0-0" > ./version.txt

# Do not error out on undefined symbols - there is a circular dependency
# between libvisual and libmesh ...
%cmake \
    -DOpenGL_GL_PREFERENCE=GLVND \
    -DUSE_SUPERBUILD=OFF \
    -DCMAKE_SHARED_LINKER_FLAGS="-flto=auto -Wl,--as-needed -Wl,--warn-unresolved-symbols -Wl,-z,now" \
    -DNG_INSTALL_DIR_INCLUDE=%{_includedir}/netgen \
    -DNG_INSTALL_DIR_LIB=%{_libdir}/netgen \
    -DCMAKE_SKIP_RPATH:BOOL=OFF \
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=OFF \
    -DCMAKE_SKIP_BUILD_RPATH=ON \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
    -DCMAKE_INSTALL_RPATH_USE_LINK_PATH:BOOL=ON \
%if %{with need_clang}
    -DCMAKE_C_COMPILER=clang \
    -DCMAKE_CXX_COMPILER=clang++ \
    -DCMAKE_AR=%{_bindir}/llvm-ar \
    -DCMAKE_RANLIB=%{_bindir}/llvm-ranlib \
    -DCMAKE_NM=%{_bindir}/llvm-nm \
    -DCMAKE_OBJDUMP=%{_bindir}/llvm-objdump \
%endif
    -DENABLE_UNIT_TESTS=ON \
    -DDOWNLOAD_DEPENDENCIES=OFF \
    -DUSE_NATIVE_ARCH=OFF \
    -DUSE_GUI=ON \
    -DUSE_PYTHON=ON \
    -DNG_INSTALL_DIR_PYTHON=%{python3_sitearch} \
%if %{with openmpi}
    -DUSE_MPI=ON \
%else
    -DUSE_MPI=OFF \
%endif
    -DUSE_OCC=%{?with_opencascade:ON}%{!?with_opencascade:OFF} \
    -DUSE_JPEG=ON \
%if %{with ffmpeg}
    -DUSE_MPEG=ON \
%else
    -DUSE_MPEG=OFF \
%endif
    ..

%cmake_build

%install
%cmake_install
rm -Rf %{buildroot}%{_datadir}/%{name}/doc

%fdupes %{buildroot}/%{_prefix}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}/%{name}
%ctest %{!?with_pytest: --exclude-regex pytest}

%files
%license LICENSE
%doc doc/*.pdf
%{_bindir}/*

%files examples
%{_datadir}/netgen

%files -n netgen-libs
%{_libdir}/netgen

%files -n python3-%{name}
%{python3_sitearch}/netgen
%{python3_sitearch}/pyngcore*.so

%files devel
%dir %{_prefix}/lib/cmake
%{_includedir}/netgen
%{_prefix}/lib/cmake/netgen

%changelog
* Fri Mar  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix RUNPATH also for Leap/SLE 15.4, which now uses
  CMAKE_SKIP_INSTALL_RPATH=ON by default.
* Mon Feb  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix RUNPATH on Leap 15.x
* Thu Jan 27 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 6.2.2105
  * no changelog provided
- Drop upstream 0001-Fix-GetTimeCounter-for-Aarch64-variants.patch
- Add patches:
  * 0001-Optionally-prefer-system-wide-pybind11.patch
  * 0001-Throw-Exception-when-shape-has-invalid-type.patch
  * 0001-Fix-signedness-for-ARM-Neon-mask-type.patch
* Mon May 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Exclude all 32bit archs, no longer supported upstream (fails to
  build).
* Mon Mar  1 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 6.2.2101
  * no changelog provided
- Properly split package: libraries (as required by e.g FreeCAD),
  python-bindings, examples and standalone GUI.
- Drop upstream fix_build.patch
- Replace 0001-Allow-compilation-on-archs-beyond-x86.patch
  with -DUSE_NATIVE_ARCH=OFF
- Fix build:
  * Add 0001-Disable-backtrace-generation.patch, do not call "nm"
    or "addr2line" from library.
  * Add 0001-Set-explicit-OBJECT-library-type-for-internal-togl.patch
  * Add 0001-Throw-in-case-enum-value-is-unhandled.patch
  * Disable -Wl,--no-undefined, libs have circular dependencies
  * Add 0001-Fix-GetTimeCounter-for-Aarch64-variants.patch
- Enable Catch2 unittests, add
  0001-Optionally-use-system-provided-Catch2.patch
* Thu Mar 21 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on ARM and PPC, only include immintrin.h when SSE is available
* Mon Mar 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Correct License:, netgen has always been LGPL-2.1-only.
- Package License file.
- Remove boost BuildRequires:, it is not used at all.
- Guard Requires: occt-devel in devel package with bcond, so it
  does not get pulled in if netgen is built without OpenCascade.
* Mon Mar 18 2019 Adrian Schröter <adrian@suse.de>
- switch to gcc7
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Remove ldconfig calls since there are only dlopened plugins,
  no standard libraries.
- Wrap description.
- Use convenient %%make_install, and run fdupes.
* Mon Mar 18 2019 Adrian Schröter <adrian@suse.de>
- update to version 6.2.1810
  obsoletes:
    allow_fine_curves.patch
    occ-pi-constant.patch
    do_stl_init.patch
- switch to cmake, obsoletes AM_PROG_AR.patch
- use obs_scm, obsoletes svnfetch.sh and netgen.sh
* Fri Dec  8 2017 adrian@suse.de
- move include files into /usr/include/netgen/
- use -fno-strict-aliasing
- add some extra header wrapper files missed by FreeCAD
* Tue Nov  7 2017 adrian@suse.de
- switch to OpenCASCADE 7.2.0
* Fri Jul 28 2017 adrian@suse.de
- switch to OpenCASCADE 7.1.0 and newer boost
* Tue Jan 31 2017 adrian@suse.de
- enable python for openSUSE Tumbleweed
* Mon Jun 13 2016 adrian@suse.de
- Using source service to follow git master (pre-6.1)
- use new oce instead of OpenCASCADE
- enable openmpi
- use fixes for rpath from Johannes Obermayer
  Sun Jan 23 2014 Torben Hansen <build at sciomnis dot com>
- Changed to upstream version
* Sun Mar 10 2013 jw@suse.com
- /usr/bin/netgen was a policy violation, -> /usr/lib/netgen
- Pulling git snapshot 5.1-dev, as the official 5.0.0 release only compiles
  with _MSC_VER; Ng_stl_Init() missing otherwise
- added full autoconf tooling to spec-file, sigh...
- renamed /usr/bin/netgen.sh to /usr/bin/netgen
* Sun Mar 10 2013 jw@suse.com
- update to 5.0.0
  * upstream changelog is empty
- obsolete fully upstreamed occ-6.5.0 patch
- patching ng/Makefile to find -lTogl1.7
- improved netgen.sh to allow parameters and preserve cwd.
- allow_fine_curves.patch added, finer defaults, extended slider range
* Sun Mar 18 2012 scorot@free.fr
- remove unneeded lam and lam-devel package requirement
* Tue May 31 2011 Werner Hoch <werner.ho@gmx.de>
- new version 4.9.13
- added patch occ-6.5.0.patch taken from debian package
  Sat Mar 27 16:46:40 CET 2010
- fixed compiling errors on gcc44
* Fri Oct 16 2009 andrea@opensuse.org
- new upstream version 4.9.11
* Wed Jun 10 2009 andrea@opensuse.org
- new upstream version
